package com.goldenwater.slaj.eme.mapper;

import java.util.List;
import org.apache.ibatis.annotations.Mapper;
import com.goldenwater.slaj.eme.domain.BusiPlanEva;

/**
 * 应急预案评估 数据层
 */
@Mapper
public interface BusiPlanEvaMapper {

    /**
     * 查询应急预案评估
     * @param guid 查询条件
     * @return 应急预案评估
     */
    BusiPlanEva selectBusiPlanEvaByGuid(String guid);

    /**
     * 查询应急预案评估列表
     * @param busiPlanEva 查询条件
     * @return 应急预案评估集合
     */
    List<BusiPlanEva> selectBusiPlanEvaList(BusiPlanEva busiPlanEva);

    /**
     * 新增应急预案评估
     * @param busiPlanEva 应急预案评估
     * @return 影响行数
     */
    int insertBusiPlanEva(BusiPlanEva busiPlanEva);

    /**
     * 修改应急预案评估
     * @param busiPlanEva 应急预案评估
     * @return 影响行数
     */
    int updateBusiPlanEva(BusiPlanEva busiPlanEva);

    /**
     * 删除应急预案评估
     * @param guid 主键
     * @return 影响行数
     */
    int deleteBusiPlanEvaByGuid(String guid);

    /**
     * 批量删除应急预案评估
     * @param guids 主键数组
     * @return 影响行数
     */
    int deleteBusiPlanEvaByGuids(String[] guids);
}
